==> core-components-file-upload-item-6.1.1.tgz: package/modern/components/status-control/status-control.js <==
import React, { useContext, useRef } from 'react';
import cn from 'classnames';
import { SuperEllipse } from '@alfalab/core-components/icon-view/super-ellipse';
import { RADIUS, MAX_PROGRESS_BAR_VALUE } from '../../const/progress-bar.js';
import { FileUploadItemContext } from '../../context/file-upload-item-context.js';
import { isUploadingStatus, isSuccessStatus, isErrorStatus } from '../../utils.js';
import { StatusControlIcon } from './components/status-control-icon/status-control-icon.js';
import { StatusControlProgressBar } from './components/status-control-progress-bar/status-control-progress-bar.js';

const styles = {"container":"file-upload-item__container_16w5v","progress":"file-upload-item__progress_16w5v","uploading":"file-upload-item__uploading_16w5v","success":"file-upload-item__success_16w5v","error":"file-upload-item__error_16w5v","progressBarTransparent":"file-upload-item__progressBarTransparent_16w5v","progressBarUploading":"file-upload-item__progressBarUploading_16w5v","progressBarSuccess":"file-upload-item__progressBarSuccess_16w5v","progressBarError":"file-upload-item__progressBarError_16w5v"};
require('./status-control.css')

const StatusControl = () => {
    const { uploadStatus = 'INITIAL', progressBar, imageUrl } = useContext(FileUploadItemContext);
    const progressRef = useRef(null);
    if (progressRef.current && progressBar) {
        progressRef.current.style.maskImage = `conic-gradient(red ${(RADIUS / MAX_PROGRESS_BAR_VALUE) * progressBar}deg, transparent 0)`;
    }
    const isTransparentProgressBar = () => uploadStatus === 'INITIAL' || uploadStatus === 'UPLOADED' || uploadStatus === 'DELETED';
    return (React.createElement("div", { className: styles.container },
        React.createElement(SuperEllipse, { size: 48, ...(imageUrl && { imageUrl }) },
            React.createElement(StatusControlIcon, null)),
        React.createElement("div", { ref: progressRef, className: cn(styles.progress, {
                [styles.uploading]: isUploadingStatus(uploadStatus),
                [styles.success]: isSuccessStatus(uploadStatus),
                [styles.error]: isErrorStatus(uploadStatus),
            }) },
            React.createElement(StatusControlProgressBar, { className: cn({
                    [styles.progressBarTransparent]: isTransparentProgressBar(),
                    [styles.progressBarUploading]: uploadStatus === 'UPLOADING',
                    [styles.progressBarSuccess]: uploadStatus === 'SUCCESS',
                    [styles.progressBarError]: uploadStatus === 'ERROR',
                }) }))));
};

export { StatusControl };

==> core-components-file-upload-item-6.2.0.tgz: package/modern/components/status-control/status-control.js <==
import React, { useContext, useRef } from 'react';
import cn from 'classnames';
import { SuperEllipse } from '@alfalab/core-components/icon-view/super-ellipse';
import { RADIUS, MAX_PROGRESS_BAR_VALUE } from '../../const/progress-bar.js';
import { FileUploadItemContext } from '../../context/file-upload-item-context.js';
import { isUploadingStatus, isSuccessStatus, isErrorStatus } from '../../utils.js';
import { StatusControlIcon } from './components/status-control-icon/status-control-icon.js';
import { StatusControlProgressBar } from './components/status-control-progress-bar/status-control-progress-bar.js';

const styles = {"container":"file-upload-item__container_1oxte","progress":"file-upload-item__progress_1oxte","uploading":"file-upload-item__uploading_1oxte","success":"file-upload-item__success_1oxte","error":"file-upload-item__error_1oxte","progressBarTransparent":"file-upload-item__progressBarTransparent_1oxte","progressBarUploading":"file-upload-item__progressBarUploading_1oxte","progressBarSuccess":"file-upload-item__progressBarSuccess_1oxte","progressBarError":"file-upload-item__progressBarError_1oxte"};
require('./status-control.css')

const StatusControl = () => {
    const { uploadStatus = 'INITIAL', progressBar, imageUrl } = useContext(FileUploadItemContext);
    const progressRef = useRef(null);
    if (progressRef.current && progressBar) {
        progressRef.current.style.maskImage = `conic-gradient(red ${(RADIUS / MAX_PROGRESS_BAR_VALUE) * progressBar}deg, transparent 0)`;
    }
    const isTransparentProgressBar = () => uploadStatus === 'INITIAL' || uploadStatus === 'UPLOADED' || uploadStatus === 'DELETED';
    return (React.createElement("div", { className: styles.container },
        React.createElement(SuperEllipse, { size: 48, ...(imageUrl && { imageUrl }) },
            React.createElement(StatusControlIcon, null)),
        React.createElement("div", { ref: progressRef, className: cn(styles.progress, {
                [styles.uploading]: isUploadingStatus(uploadStatus),
                [styles.success]: isSuccessStatus(uploadStatus),
                [styles.error]: isErrorStatus(uploadStatus),
            }) },
            React.createElement(StatusControlProgressBar, { className: cn({
                    [styles.progressBarTransparent]: isTransparentProgressBar(),
                    [styles.progressBarUploading]: uploadStatus === 'UPLOADING',
                    [styles.progressBarSuccess]: uploadStatus === 'SUCCESS',
                    [styles.progressBarError]: uploadStatus === 'ERROR',
                }) }))));
};

export { StatusControl };
